;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;		How does mispecification help/hurt?
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Some parameters:
(def n 20)
(def xstart -1)
(def xend 1)
(def xvals (rseq xstart xend n))
(def yvals (repeat 0 n))

;; Just a plot of the true and mis-specified models:
(let ()
  (lines on)
  (domain xstart xend)
  ;; logistic:
  (defun ff(x) (exp x))
  ;; approximate arctan:
  (defun gg(x) (+ 
		(/ (* (exp 1) x (+ x 1)) 2)
		(/ (* (- x 1) (+ x 1)) -1)
		(/ (* (exp -1) x (- x 1)) 2)
		))
  (plot gg)
  (send my-plot :add-plot-item (list 'function #'ff))
  (postscript "misspec2.ps")
  )

(derfunc ggp gg x)

(let ()
  ;; Two helpers:
  (defun guess-alpha-a(x)
    (ggp x)
    )
  (defun guess-alpha-b(x)
    (gg x)
    )

  ;; find alpha by linear regression:
  (regress 
   (list 
    (mapcar #'guess-alpha-b xvals)
    )
   (mapcar #'guess-alpha-a xvals)
   ;; no intercept!
   :intercept nil
   )
  
  ;; find alpha by non-linear regression:
  (defun nreg-fun(theta)
    (let* (
	   (alpha (first theta))
	   (xx xvals)
	   )
      (-
       (* alpha (guess-alpha-b xx))
       (guess-alpha-a xx)
       )
      )
    )
  (def nreg
       (nreg-model
	;; #'nreg-fun is the X-part of the non-linear regression
	#'nreg-fun
	;; yvals is the Y-part of the non-linear regression
	yvals
	;; .3 is ... the initial guess
	(list .03)
	)
       )
  )
	 
